==> fastdds_2.5.0+ds.orig.tar.xz: Fast-DDS-2.5.0/roadmap.md <==
# Fast RTPS Roadmap

This product is a FIWARE Generic Enabler.
If you would like to learn about the overall Roadmap of FIWARE, please check section "Roadmap" on the FIWARE Catalogue.

## Introduction

This section elaborates on proposed new features or tasks which are expected to be added to the product in the
foreseeable future.
There should be no assumption of a commitment to deliver these features on specific dates or in the order given.
The development team will be doing their best to follow the proposed dates and priorities, but please bear in mind
that plans to work on a given feature or task may be revised.
All information is provided as a general guidelines only, and this section may be revised to provide newer information
at any time.

Disclaimer:

* This section has been last updated in Sep 2021.
  Please take into account its content could be obsolete.

## Short term

The following list of features are planned to be addressed in the short term, and incorporated into the following
minor release of the product:

* Content filtered topic support on DataReader
* PKCS#11 support for private keys
* Python binding
* Support for dynamic network interfaces
* ReadCondition implementation

## Medium term

The following list of features are planned to be addressed in the medium term, typically within the subsequent
release(s) generated in the next **9 months** after next planned release:

* Service aware DataWriter
* Partition QoS on DataReader and DataWriter
* DDS x-types 1.2

## Long term

The following list of features are proposals regarding the longer-term evolution of the product even though development
of these features has not yet been scheduled for a release in the near future.
Please feel free to contact us if you wish to get involved in the implementation or influence the roadmap.

* Full DDS API compliance
* Compliance with DDS-XML
* Low bandwidth transports
* ISO 26262 compliance

==> fastdds_2.7.1+ds.orig.tar.xz: Fast-DDS-2.7.1/roadmap.md <==
# Fast RTPS Roadmap

This product is a FIWARE Generic Enabler.
If you would like to learn about the overall Roadmap of FIWARE, please check section "Roadmap" on the FIWARE Catalogue.

## Introduction

This section elaborates on proposed new features or tasks which are expected to be added to the product in the
foreseeable future.
There should be no assumption of a commitment to deliver these features on specific dates or in the order given.
The development team will be doing their best to follow the proposed dates and priorities, but please bear in mind
that plans to work on a given feature or task may be revised.
All information is provided as a general guidelines only, and this section may be revised to provide newer information
at any time.

Disclaimer:

* This section has been last updated in July 2022.
  Please take into account its content could be obsolete.

## Short term

The following list of features are planned to be addressed in the short term, and incorporated into the following
minor release of the product:

* Complete support for dynamic network interfaces
* ReadCondition implementation
* Secure Discovery Server
* Android support
* Support for Ownership and Time-based filter QoS.
* SNI support for TLS.

## Medium term

The following list of features are planned to be addressed in the medium term, typically within the subsequent
release(s) generated in the next **9 months** after next planned release:

* Service aware DataWriter
* DDS-XTypes 1.3

## Long term

The following list of features are proposals regarding the longer-term evolution of the product even though development
of these features has not yet been scheduled for a release in the near future.
Please feel free to contact us if you wish to get involved in the implementation or influence the roadmap.

* Full DDS API compliance
* Compliance with DDS-XML
* Low bandwidth transports
* ISO 26262 compliance
